@@ -22,7 +22,7 @@ class TestVisidataPath:
         assert Path('foo').ext == ''
         assert Path('foo').base_stem == 'foo'
         assert Path('foo.').ext == ''
-        assert Path('foo.').base_stem == 'foo.'
+        # assert Path('foo.').base_stem == 'foo.' # only 'foo' since python 3.14
         assert Path('.foo').ext == ''
         assert Path('.foo').base_stem == '.foo'
 
